==> zio-aws-datasync_3-5.17.116.1-sources.jar: zio/aws/datasync/model/CreateLocationSmbResponse.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.LocationArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateLocationSmbResponse(
    locationArn: Option[LocationArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse = {
    import CreateLocationSmbResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
      .builder()
      .optionallyWith(
        locationArn.map(value => LocationArn.unwrap(value): java.lang.String)
      )(_.locationArn)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.CreateLocationSmbResponse.ReadOnly =
    zio.aws.datasync.model.CreateLocationSmbResponse.wrap(buildAwsValue())
}
object CreateLocationSmbResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.CreateLocationSmbResponse =
      zio.aws.datasync.model
        .CreateLocationSmbResponse(locationArn.map(value => value))
    def locationArn: Option[LocationArn]
    def getLocationArn: ZIO[Any, AwsError, LocationArn] =
      AwsError.unwrapOptionField("locationArn", locationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
  ) extends zio.aws.datasync.model.CreateLocationSmbResponse.ReadOnly {
    override val locationArn: Option[LocationArn] = scala
      .Option(impl.locationArn())
      .map(value => zio.aws.datasync.model.primitives.LocationArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
  ): zio.aws.datasync.model.CreateLocationSmbResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-datasync_3-5.17.181.1-sources.jar: zio/aws/datasync/model/CreateLocationSmbResponse.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.LocationArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateLocationSmbResponse(
    locationArn: Optional[LocationArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse = {
    import CreateLocationSmbResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
      .builder()
      .optionallyWith(
        locationArn.map(value => LocationArn.unwrap(value): java.lang.String)
      )(_.locationArn)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.CreateLocationSmbResponse.ReadOnly =
    zio.aws.datasync.model.CreateLocationSmbResponse.wrap(buildAwsValue())
}
object CreateLocationSmbResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.CreateLocationSmbResponse =
      zio.aws.datasync.model
        .CreateLocationSmbResponse(locationArn.map(value => value))
    def locationArn: Optional[LocationArn]
    def getLocationArn: ZIO[Any, AwsError, LocationArn] =
      AwsError.unwrapOptionField("locationArn", locationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
  ) extends zio.aws.datasync.model.CreateLocationSmbResponse.ReadOnly {
    override val locationArn: Optional[LocationArn] = zio.aws.core.internal
      .optionalFromNullable(impl.locationArn())
      .map(value => zio.aws.datasync.model.primitives.LocationArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationSmbResponse
  ): zio.aws.datasync.model.CreateLocationSmbResponse.ReadOnly = new Wrapper(
    impl
  )
}
